@@ -19,8 +19,7 @@ class ExtensionTest(unittest.TestCase):
         self.assertIn('display_name', schema)
         self.assertIn('base_url', schema)
         self.assertIn('country', schema)
-        self.assertIn('browse_charts', schema)
-        self.assertIn('browse_limit', schema)
-        self.assertIn('root_genre_id', schema)
         self.assertIn('explicit', schema)
-        self.assertIn('timeout', schema)
+        self.assertIn('charts', schema)
+        self.assertIn('charts_label', schema)
+        self.assertIn('root_genre_id', schema)
